@@ -24,6 +24,7 @@
 #  include "sys/marcel_flags.h"
 #endif
 #include <stdarg.h>
+#include <stdint.h>
 
 #include "fxt.h"
 
@@ -145,11 +146,14 @@ __END_TEMPLATE__
 } while (0)
 
 /******************************************************/
-/* Ne JAMAIS appeler fut_getstampedbuffer directement */
-/* Interface pouvant changer sans pravis             */
+/* NEVER call fut_getstampedbuffer directly           */
+/* Interface can change without forewarning           */
 /******************************************************/
 extern unsigned long* fut_getstampedbuffer(unsigned long code, int size);
 
+/* This can be overriden by the user */
+extern uint64_t fut_getstamp(void);
+
 inline static void
 #ifndef __cplusplus
 __attribute__((no_instrument_function))
