@@ -203,8 +203,10 @@ static unsigned long trash_buffer[8];
 extern int allow_fut_flush;
 extern pthread_mutex_t fut_flush_lock;
 
-unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec,
-					 unsigned long code)
+#ifdef __GNUC__
+__attribute__((weak))
+#endif
+uint64_t fut_getstamp(void)
 {
 	unsigned long long tick;
 #ifdef HAVE_CLOCK_GETTIME
@@ -219,8 +221,13 @@ unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec,
 #else
 	TBX_GET_TICK(tick);
 #endif
+	return tick;
+}
 
-	rec->tick = tick;
+unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec,
+					 unsigned long code)
+{
+	rec->tick = fut_getstamp();
 #ifdef MA__FUT_RECORD_TID
 	rec->tid=(unsigned long)MARCEL_SELF;
 #else
@@ -229,7 +236,7 @@ unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec,
 		rec->tid = syscall(SYS_gettid);
 #  else
 #ifdef __MINGW32__
-		rec->tid = GetCurrentThread();
+		rec->tid = GetCurrentThreadId();
 #else
 		rec->tid = pthread_self();
 #endif
