@@ -26,9 +26,10 @@
 #include <time.h>
 #include <fcntl.h>
 #include <string.h>
-#include <sys/utsname.h>
 #include <sys/types.h>
+#ifndef __MINGW32__
 #include <sys/times.h>
+#endif
 #include <pthread.h>
 #include "fxt.h"
 #include "fut.h"
@@ -94,7 +95,7 @@ void fut_set_filename(char* filename)
 	      filename, fut_filename);
     free(fut_filename);
   }
-  asprintf(&fut_filename, "%s", filename);
+  fut_filename = strdup(filename);
 }
 
 void __fut_reset_pointers()
@@ -104,13 +105,19 @@ void __fut_reset_pointers()
 
 void dumptime( time_t *the_time, clock_t *the_jiffies)
 {
+#ifndef __MINGW32__
   struct tms cur_time;
+#endif
 
   if( (*the_time = time(NULL)) == -1 )
     perror("time");
 
+#ifdef __MINGW32__
+  *the_jiffies = 0;
+#else
   if( (*the_jiffies = times(&cur_time)) == (clock_t) -1 )
     perror("times");
+#endif
 }
 
 
